Cal

Struct Cal 

pub struct Cal<Ca, Tz>
where Ca: AsCalendar, Tz: TimeZone,
{ /* private fields */ }
Available on crate feature icu only.
A calendar based on icu4x

Implementations

Source

impl<Ca, Tz> Cal<Ca, Tz>
where Ca: AsCalendar, Tz: TimeZone,

pub fn new(cal: Ca, tz: Tz) -> Cal<Ca, Tz>

Create a calendar with the given settings

This allows creating a kine calendar that deals with time in the tz timezone, and whose days are in the cal calendar.